@@ -1,7 +1,10 @@
 from flask import g,render_template, request, session
 from gaelib.auth.decorators import auth_required, access_control
 from gaelib.auth.models import User, UserRole
-from gaelib.env import get_dashboard_url_prefix, get_env, get_post_login_page, get_sidebar_template
+from gaelib.env import (get_dashboard_url_prefix, 
+                        get_env, 
+                        get_post_login_page, 
+                        get_sidebar_template)
 from gaelib.view.base_view import BaseHttpHandler
 
 
