@@ -4,4 +4,6 @@
 """
 DASHBOARD_URL_PREFIX = 'admindashboard'
 POST_LOGIN_PAGE = 'users'
-SIDEBAR_TEMPLATE = 'dashboard/operations_sidebar'
\ No newline at end of file
+SIDEBAR_TEMPLATE = 'dashboard/operations_sidebar'
+PARAMETER_LOGGING = 'true'
+SESSION_SECRET = ''
\ No newline at end of file
