@@ -1,6 +1,6 @@
 import os
-from flask import g, jsonify, redirect, request, session
 
+from flask import g, jsonify, redirect, request, session
 import constants
 import gaelib.defaults as defaults
 
@@ -20,7 +20,7 @@ def is_staging():
 def get_app_or_default_prop(prop_name):
   try:
     prop_value = getattr(constants, prop_name)
-  except AttributeError:
+  except (AttributeError, ModuleNotFoundError):
     prop_value = ''
   if not prop_value:
     prop_value = getattr(defaults, prop_name)
